==> wizzi-core-0.6.16.tgz: package/readme.md <==
# wizzi-core - ver 0.6 - plugin package

A Wizzi Factory plugin with core schemas and artifact generators.

## Work still in progress

Availability of features will be announced
on [Twitter](https://twitter.com/wizziteam) and [Facebook](https://www.facebook.com/wizzifactory)

## Features
### Implemented wizzi models

<table>
<tr>
<th>Schema</th>
<th>Descriptionn</th>
<th>Model transformers</th>
<th>Artifacts</th>
</tr>
<tr>
<td>wfjob</td>
<td>Wizzi job definition</td>
<td>

<table>
</table>

<td>

<table>
</table>

</tr>
<tr>
<td>wfschema</td>
<td>Wizzi schema definition</td>
<td>

<table>
</table>

<td>

<table>
<tr>
<td>wfschema/factory</td>
</tr>
<tr>
<td>wfschema/model</td>
</tr>
<tr>
<td>wfschema/html_docs</td>
</tr>
<tr>
<td>wfschema/json_docs</td>
</tr>
<tr>
<td>wfschema/test</td>
</tr>
</table>

</tr>
<tr>
<td>json</td>
<td>json wizzi language model</td>
<td>

<table>
</table>

<td>

<table>
<tr>
<td>json/document</td>
</tr>
<tr>
<td>json/export</td>
</tr>
</table>

</tr>
<tr>
<td>xml</td>
<td>xml wizzi language model</td>
<td>

<table>
</table>

<td>

<table>
<tr>
<td>xml/document</td>
</tr>
<tr>
<td>xml/export</td>
</tr>
</table>

</tr>
<tr>
<td>text</td>
<td>text wizzi language model</td>
<td>

<table>
</table>

<td>

<table>
<tr>
<td>text/document</td>
</tr>
</table>

</tr>
<tr>
<td>ittf</td>
<td>ittf wizzi language model</td>
<td>

<table>
<tr>
<td>ittf/html_prettify</td>
</tr>
</table>

<td>

<table>
<tr>
<td>ittf/document</td>
</tr>
</table>

</tr>
</table>



<p>Wizzi plugins are documented\b<a href="https://wizzifactory.github.io/docs/plugins.html">here</a>.</p>



<p>You can find a few samples in the /example folder, but you can find more in the\b<a href="https://github.com/wizzifactory/wizzi-demo">demo package</a>.</p>

## Source and generation
wizzi-core is generated using the wizzi factory ver 0.5

## The Wizzi Factory - ver 0.6

A set of tools for model driven development.


<p><a href="https://wizzifactory.github.io/">Project page</a></p>

## Built With
* [Nodejs](https://nodejs.org)

* [Wizzi Factory](https://github.com/wizzifactory)


## License

<p>This project is licensed under the MIT License - see the\b<a href="license.txt">license.txt\b</a><p>for details.</p></p>

==> wizzi-core-0.7.0.tgz: package/readme.md <==
# wizzi-core - ver 0.6 - plugin package

A Wizzi Factory plugin with core schemas and artifact generators.

## Work still in progress

Availability of features will be announced
on [Twitter](https://twitter.com/wizziteam) and [Facebook](https://www.facebook.com/wizzifactory)

## Features
### Implemented wizzi models

<table>
<tr>
<th>Schema</th>
<th>Descriptionn</th>
<th>Model transformers</th>
<th>Artifacts</th>
</tr>
<tr>
<td>wfjob</td>
<td>Wizzi job definition</td>
<td>

<table>
</table>

<td>

<table>
</table>

</tr>
<tr>
<td>wfschema</td>
<td>Wizzi schema definition</td>
<td>

<table>
</table>

<td>

<table>
<tr>
<td>wfschema/factory</td>
</tr>
<tr>
<td>wfschema/model</td>
</tr>
<tr>
<td>wfschema/html_docs</td>
</tr>
<tr>
<td>wfschema/json_docs</td>
</tr>
<tr>
<td>wfschema/test</td>
</tr>
</table>

</tr>
<tr>
<td>json</td>
<td>json wizzi language model</td>
<td>

<table>
</table>

<td>

<table>
<tr>
<td>json/document</td>
</tr>
<tr>
<td>json/export</td>
</tr>
</table>

</tr>
<tr>
<td>xml</td>
<td>xml wizzi language model</td>
<td>

<table>
</table>

<td>

<table>
<tr>
<td>xml/document</td>
</tr>
<tr>
<td>xml/export</td>
</tr>
</table>

</tr>
<tr>
<td>text</td>
<td>text wizzi language model</td>
<td>

<table>
</table>

<td>

<table>
<tr>
<td>text/document</td>
</tr>
</table>

</tr>
<tr>
<td>ittf</td>
<td>ittf wizzi language model</td>
<td>

<table>
<tr>
<td>ittf/html_prettify</td>
</tr>
</table>

<td>

<table>
<tr>
<td>ittf/document</td>
</tr>
</table>

</tr>
</table>



<p>Wizzi plugins are documented<a href="https://wizzifactory.github.io/docs/plugins.html">here</a>.</p>



<p>You can find a few samples in the /example folder, but you can find more in the<a href="https://github.com/wizzifactory/wizzi/packages/wizzi-demo">demo package</a>.</p>

## Source and generation
wizzi-core is generated using the wizzi factory ver 0.5

## The Wizzi Factory

A model driven artifact factory.


<p><a href="https://wizzifactory.github.io/">Project page</a></p>

## Built With
* [Nodejs](https://nodejs.org)

* [Wizzi Factory](https://github.com/wizzifactory)


## License

<p>This project is licensed under the MIT License - see the<a href="license.txt">license.txt</a><p>for details.</p></p>
